import { httpRequest } from '@/services/http'
import { HttpParams } from '@/services/http/interface'

/**
 * 查询仓单成交明细
 */
 export function queryWrTradeDetail(params: HttpParams<{ req: Partial< Model.WrTradeDetailReq>, rsp: Model.WrTradeDetailRsp[] }>) {
    return httpRequest('/WrTrade2/QueryWrTradeDetail', 'get', params);
}

/**
 * 查询仓单委托单
 */
 export function queryWrOrderDetail(params: HttpParams<{ req: Partial<Model.WrOrderDetailReq>, rsp: Model.WrOrderDetailRsp[] }>) {
    return httpRequest('/WrTrade2/QueryWrOrderDetail', 'get', params);
}

/**
 * 查询我的订单-采购订单
 */
 export function queryTHJPurchaseTradeDetail(params: HttpParams<{ req: Model.THJPurchaseTradeDetailReq, rsp: Model.THJPurchaseTradeDetailRsp[] }>) {
    return httpRequest('/Ferroalloy/QueryTHJPurchaseTradeDetail', 'get', params);
}

/**
 * 查询仓单持有记录
 */
 export function queryHoldLB(params: HttpParams<{ req: Model.HoldLBReq, rsp: Model.HoldLBRsp[] }>) {
    return httpRequest('/WrTrade2/QueryHoldLB', 'get', params);
}

/**
 * 查询提货申请
 */
 export function queryWrOutInApply(params: HttpParams<{ req: Model.WrOutInApplyReq, rsp: Model.WrOutInApplyRsp[] }>) {
    return httpRequest('/WrTrade2/QueryWrOutInApply', 'get', params);
}

/**
 * 查询我的推广-推广收益
 */
 export function queryTHJPromotionIncome(params: HttpParams<{ req: Model.THJPromotionIncomeReq, rsp: Model.THJPromotionIncomeRsp[] }>) {
    return httpRequest('/Ferroalloy/QueryTHJPromotionIncome', 'get', params);
}

/**
 * 查询我的推广-推广收益-明细
 */
 export function queryTHJPromotionIncomeDetail(params: HttpParams<{ req: Model.THJPromotionIncomeDetailReq, rsp: Model.THJPromotionIncomeDetailRsp[] }>) {
    return httpRequest('/Ferroalloy/QueryTHJPromotionIncomeDetail', 'get', params);
}

/**
 * 查询我的订单-转让/受让订单
 */
 export function queryTHJPurchaseTransferOrder(params: HttpParams<{ req: Model.THJPurchaseTransferOrderReq, rsp: Model.THJPurchaseTransferOrderRsp[] }>) {
    return httpRequest('/Ferroalloy/QueryTHJPurchaseTransferOrder', 'get', params);
}

/**
 * 查询我的订单-转让/受让订单-详情
 */
 export function queryTHJPurchaseTransferOrderDetail(params: HttpParams<{ req: Model.THJPurchaseTransferOrderDetailReq, rsp: Model.THJPurchaseTransferOrderDetailRsp[] }>) {
    return httpRequest('/Ferroalloy/QueryTHJPurchaseTransferOrderDetail', 'get', params);
}